@@ -31,6 +31,12 @@ class RestClient(Salesforce):
         segments = []
         segments.append(text)
         
+        if len(mention_ids) > 0:
+            segments.append({
+                             "type":"Text",
+                             "text":"\n\ncc: "
+                             })
+            
         for mention_id in mention_ids:
             segments.append({
                              "type":"mention",
