@@ -3,7 +3,13 @@ Created on Dec 4, 2013
 
 @author: scrosby
 '''
-import httplib, re
+try:
+    import httplib
+except ImportError:
+    import http.client
+    httplib = http.client
+    
+import re
 
 class SoapSession:
     def __init__(self, instance='login.salesforce.com', session_id=None):
@@ -26,13 +32,13 @@ class SoapSession:
         conn = httplib.HTTPSConnection(self.instance)
         conn.request('POST', '/services/Soap/c/v29.0', body, headers)
         response = conn.getresponse()
-        data = response.read()
+        data = str(response.read())
         conn.close()
         try:
-            regex = re.compile("<sessionId>(.*)</sessionId>", re.MULTILINE)
+            regex = re.compile(str("<sessionId>(.*)</sessionId>"), re.MULTILINE)
             match = regex.search(data)
             sessionId = match.group(1)
-            self.sessionId = sessionId
+            self.sessionId = str(sessionId)
         except:
             self.sessionId = None
             raise Exception('Login Failed')
